@@ -3,11 +3,12 @@
 #include <engine/server/databases/connection_pool.h>
 
 #if defined(CONF_MYSQL)
-#include <mysql.h>
-
 #include <base/tl/threading.h>
+
 #include <engine/console.h>
 
+#include <mysql.h>
+
 #include <atomic>
 #include <memory>
 #include <vector>
@@ -152,7 +153,7 @@ CMysqlConnection::CMysqlConnection(CMysqlConfig Config) :
 	g_MysqlNumConnections += 1;
 	dbg_assert(g_MysqlState == MYSQLSTATE_INITIALIZED, "MySQL library not in initialized state");
 
-	mem_zero(m_aErrorDetail, sizeof(m_aErrorDetail));
+	m_aErrorDetail[0] = '\0';
 	mem_zero(&m_Mysql, sizeof(m_Mysql));
 	mysql_init(&m_Mysql);
 }
