@@ -1,19 +1,21 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 
-#include <engine/shared/config.h>
+#include "camera.h"
+
+#include "controls.h"
 
 #include <base/log.h>
 #include <base/math.h>
 #include <base/vmath.h>
+
+#include <engine/shared/config.h>
+
 #include <game/client/gameclient.h>
 #include <game/collision.h>
 #include <game/localization.h>
 #include <game/mapitems.h>
 
-#include "camera.h"
-#include "controls.h"
-
 #include <limits>
 
 CCamera::CCamera()
@@ -47,7 +49,7 @@ CCamera::CCamera()
 	m_CanUseCameraInfo = false;
 	m_UsingAutoSpecCamera = false;
 
-	mem_zero(m_aAutoSpecCameraTooltip, sizeof(m_aAutoSpecCameraTooltip));
+	m_aAutoSpecCameraTooltip[0] = '\0';
 }
 
 float CCamera::CameraSmoothingProgress(float CurrentTime) const
