@@ -4,13 +4,12 @@
 #include <base/math.h>
 #include <base/system.h>
 
+#include <engine/external/json-parser/json.h>
 #include <engine/graphics.h>
+#include <engine/shared/jsonwriter.h>
 #include <engine/shared/localization.h>
 #include <engine/textrender.h>
 
-#include <engine/external/json-parser/json.h>
-#include <engine/shared/jsonwriter.h>
-
 #include <game/client/components/touch_controls.h>
 #include <game/client/gameclient.h>
 #include <game/client/lineinput.h>
@@ -88,7 +87,7 @@ void CMenusIngameTouchControls::RenderTouchButtonEditor(CUIRect MainView)
 	case EElementType::LAYOUT: Changed |= RenderLayoutSettingBlock(Block); break;
 	case EElementType::VISIBILITY: Changed |= RenderVisibilitySettingBlock(Block); break;
 	case EElementType::BEHAVIOR: Changed |= RenderBehaviorSettingBlock(Block); break;
-	default: dbg_assert(false, "Unknown m_EditElement = %d.", m_EditElement);
+	default: dbg_assert(false, "Unknown m_EditElement = %d.", (int)m_EditElement);
 	}
 
 	// Save & Cancel & Hint.
@@ -170,12 +169,12 @@ void CMenusIngameTouchControls::RenderTouchButtonEditor(CUIRect MainView)
 		}
 		else
 		{
-			CTouchControls::CUnitRect FreeRect = GameClient()->m_TouchControls.UpdatePosition(GameClient()->m_TouchControls.ShownRect().value(), true);
+			CTouchControls::CUnitRect FreeRect = GameClient()->m_TouchControls.UpdatePosition(GameClient()->m_TouchControls.ShownRect().value(), m_CachedShape, true);
 			if(FreeRect.m_X == -1)
 			{
 				FreeRect.m_W = CTouchControls::BUTTON_SIZE_MINIMUM;
 				FreeRect.m_H = CTouchControls::BUTTON_SIZE_MINIMUM;
-				FreeRect = GameClient()->m_TouchControls.UpdatePosition(FreeRect, true);
+				FreeRect = GameClient()->m_TouchControls.UpdatePosition(FreeRect, m_CachedShape, true);
 				if(FreeRect.m_X == -1)
 				{
 					GameClient()->m_Menus.PopupMessage(Localize("No space for button"), Localize("There is not enough space available to place another button."), Localize("Ok"));
@@ -1154,7 +1153,7 @@ bool CMenusIngameTouchControls::CheckCachedSettings() const
 	{
 		vpErrors.emplace_back(Localize("Button position is outside of the screen."));
 	}
-	if(GameClient()->m_TouchControls.IsRectOverlapping({X, Y, W, H}))
+	if(GameClient()->m_TouchControls.IsRectOverlapping({X, Y, W, H}, m_CachedShape))
 	{
 		vpErrors.emplace_back(Localize("The selected button is overlapping with other buttons."));
 	}
@@ -1343,7 +1342,7 @@ void CMenusIngameTouchControls::ResetButtonPointers()
 // New button doesn't create a real button, instead it reset the Samplebutton to cache every setting. When saving a the Samplebutton then a real button will be created.
 void CMenusIngameTouchControls::NewVirtualButton()
 {
-	CTouchControls::CUnitRect FreeRect = GameClient()->m_TouchControls.UpdatePosition({0, 0, CTouchControls::BUTTON_SIZE_MINIMUM, CTouchControls::BUTTON_SIZE_MINIMUM}, true);
+	CTouchControls::CUnitRect FreeRect = GameClient()->m_TouchControls.UpdatePosition({0, 0, CTouchControls::BUTTON_SIZE_MINIMUM, CTouchControls::BUTTON_SIZE_MINIMUM}, CTouchControls::EButtonShape::RECT, true);
 	ResetButtonPointers();
 	ResetCachedSettings();
 	SetPosInputs(FreeRect);
