@@ -290,6 +290,18 @@ void *CGameClient::TranslateGameMsg(int *pMsgId, CUnpacker *pUnpacker, int Conn)
 
 		return s_aRawMsg;
 	}
+	else if(*pMsgId == protocol7::NETMSGTYPE_SV_CHECKPOINT)
+	{
+		*pMsgId = NETMSGTYPE_SV_DDRACETIME;
+		protocol7::CNetMsg_Sv_Checkpoint *pMsg7 = (protocol7::CNetMsg_Sv_Checkpoint *)pRawMsg;
+		::CNetMsg_Sv_DDRaceTime *pMsg = (::CNetMsg_Sv_DDRaceTime *)s_aRawMsg;
+
+		pMsg->m_Time = 1;
+		pMsg->m_Finish = 0;
+		pMsg->m_Check = pMsg7->m_Diff / 10;
+
+		return s_aRawMsg;
+	}
 	else if(*pMsgId == protocol7::NETMSGTYPE_SV_COMMANDINFOREMOVE)
 	{
 		*pMsgId = NETMSGTYPE_SV_COMMANDINFOREMOVE;
