@@ -16,12 +16,14 @@ struct SEditBoxDropdownContext
 };
 
 // TODO: add and use constants for other special Checked-values in CEditor::GetButtonColor
-namespace EditorButtonChecked {
-[[maybe_unused]] static constexpr int DANGEROUS_ACTION = 9;
+namespace EditorButtonChecked
+{
+	[[maybe_unused]] static constexpr int DANGEROUS_ACTION = 9;
 }
 
-namespace EditorFontSizes {
-[[maybe_unused]] static constexpr float MENU = 10.0f;
+namespace EditorFontSizes
+{
+	[[maybe_unused]] static constexpr float MENU = 10.0f;
 }
 
 #endif
