@@ -3,6 +3,8 @@
 
 #include <game/map/render_map.h>
 #include <game/mapitems.h>
+
+#include <array>
 #include <vector>
 
 class CEnvelope
@@ -23,7 +25,7 @@ public:
 
 	std::pair<float, float> GetValueRange(int ChannelMask);
 	void Eval(float Time, ColorRGBA &Result, size_t Channels);
-	void AddPoint(CFixedTime Time, int v0, int v1 = 0, int v2 = 0, int v3 = 0);
+	void AddPoint(CFixedTime Time, std::array<int, CEnvPoint::MAX_CHANNELS> aValues);
 	float EndTime() const;
 	int FindPointIndex(CFixedTime Time) const;
 	int GetChannels() const;
