@@ -21,7 +21,7 @@ class CLayerSpeedup : public CLayerTiles
 public:
 	CLayerSpeedup(CEditor *pEditor, int w, int h);
 	CLayerSpeedup(const CLayerSpeedup &Other);
-	~CLayerSpeedup();
+	~CLayerSpeedup() override;
 
 	CSpeedupTile *m_pSpeedupTile;
 	int m_SpeedupForce;
@@ -31,11 +31,11 @@ public:
 	void Resize(int NewW, int NewH) override;
 	void Shift(EShiftDirection Direction) override;
 	[[nodiscard]] bool IsEmpty() const override;
-	void BrushDraw(std::shared_ptr<CLayer> pBrush, vec2 WorldPos) override;
+	void BrushDraw(CLayer *pBrush, vec2 WorldPos) override;
 	void BrushFlipX() override;
 	void BrushFlipY() override;
 	void BrushRotate(float Amount) override;
-	void FillSelection(bool Empty, std::shared_ptr<CLayer> pBrush, CUIRect Rect) override;
+	void FillSelection(bool Empty, CLayer *pBrush, CUIRect Rect) override;
 
 	EditorTileStateChangeHistory<SSpeedupTileStateChange> m_History;
 	void ClearHistory() override
