@@ -19,7 +19,7 @@ class CLayerTele : public CLayerTiles
 public:
 	CLayerTele(CEditor *pEditor, int w, int h);
 	CLayerTele(const CLayerTele &Other);
-	~CLayerTele();
+	~CLayerTele() override;
 
 	CTeleTile *m_pTeleTile;
 	unsigned char m_TeleNum;
@@ -28,11 +28,11 @@ public:
 	void Resize(int NewW, int NewH) override;
 	void Shift(EShiftDirection Direction) override;
 	[[nodiscard]] bool IsEmpty() const override;
-	void BrushDraw(std::shared_ptr<CLayer> pBrush, vec2 WorldPos) override;
+	void BrushDraw(CLayer *pBrush, vec2 WorldPos) override;
 	void BrushFlipX() override;
 	void BrushFlipY() override;
 	void BrushRotate(float Amount) override;
-	void FillSelection(bool Empty, std::shared_ptr<CLayer> pBrush, CUIRect Rect) override;
+	void FillSelection(bool Empty, CLayer *pBrush, CUIRect Rect) override;
 	int FindNextFreeNumber(bool Checkpoint) const;
 	bool ContainsElementWithId(int Id, bool Checkpoint) const;
 	void GetPos(int Number, int Offset, int &TeleX, int &TeleY);
@@ -41,7 +41,7 @@ public:
 	ivec2 m_GotoTeleLastPos;
 
 	EditorTileStateChangeHistory<STeleTileStateChange> m_History;
-	inline void ClearHistory() override
+	void ClearHistory() override
 	{
 		CLayerTiles::ClearHistory();
 		m_History.clear();
