@@ -19,7 +19,7 @@ class CLayerTune : public CLayerTiles
 public:
 	CLayerTune(CEditor *pEditor, int w, int h);
 	CLayerTune(const CLayerTune &Other);
-	~CLayerTune();
+	~CLayerTune() override;
 
 	CTuneTile *m_pTuneTile;
 	unsigned char m_TuningNumber;
@@ -27,11 +27,11 @@ public:
 	void Resize(int NewW, int NewH) override;
 	void Shift(EShiftDirection Direction) override;
 	[[nodiscard]] bool IsEmpty() const override;
-	void BrushDraw(std::shared_ptr<CLayer> pBrush, vec2 WorldPos) override;
+	void BrushDraw(CLayer *pBrush, vec2 WorldPos) override;
 	void BrushFlipX() override;
 	void BrushFlipY() override;
 	void BrushRotate(float Amount) override;
-	void FillSelection(bool Empty, std::shared_ptr<CLayer> pBrush, CUIRect Rect) override;
+	void FillSelection(bool Empty, CLayer *pBrush, CUIRect Rect) override;
 	int FindNextFreeNumber() const;
 	bool ContainsElementWithId(int Id) const;
 	void GetPos(int Number, int Offset, ivec2 &Pos);
@@ -40,7 +40,7 @@ public:
 	ivec2 m_GotoTuneLastPos;
 
 	EditorTileStateChangeHistory<STuneTileStateChange> m_History;
-	inline void ClearHistory() override
+	void ClearHistory() override
 	{
 		CLayerTiles::ClearHistory();
 		m_History.clear();
