@@ -2,9 +2,12 @@
 #define GAME_EDITOR_QUADART_H
 
 #include <base/types.h>
+
 #include <engine/image.h>
+
 #include <game/editor/mapitems/layer_quads.h>
 #include <game/mapitems.h>
+
 #include <memory>
 #include <optional>
 
@@ -29,7 +32,7 @@ private:
 	ivec2 GetOptimizedQuadSize(const ColorRGBA &Pixel, const ivec2 &Pos);
 	void MarkPixelAsVisited(const ivec2 &Pos, const ivec2 &Size);
 
-	size_t FindSuperPixelSize(const ColorRGBA &Pixel, const ivec2 &Pos, const size_t CurrentSize);
+	size_t FindSuperPixelSize(const ColorRGBA &Pixel, const ivec2 &Pos, size_t CurrentSize);
 
 	ColorRGBA GetPixelClamped(const ivec2 &Pos) const;
 	bool IsPixelOptimizable(const ivec2 &Pos, const ColorRGBA &Pixel) const;
